from op5helpers import *

api_endpoint = 'https://'+os.environ.get("MONITOR_SERVER", 'localhost')+'/api/help/config'

def test_manual_defaults_to_html():
    r = requests.get(api_endpoint, auth=authed_user, verify=False)
    eq_(r.status_code, 200)
    eq_(r.headers['content-type'], 'text/html; charset=utf-8', r.text)

def test_lists_valid_object_types():
    r = requests.get(api_endpoint, auth=authed_user, verify=False)
    eq_(r.status_code, 200)

    valid_object_types = [
        'command',
        'contact',
        'contactgroup',
        'host',
        'hostdependency',
        'hostgroup',
        'service',
        'servicedependency',
        'servicegroup',
        'timeperiod',
        'user',
    ]

    invalid_object_types = [
        'a_dummy_object',
        'pnp',
        'top_bar',
    ]

    for var in valid_object_types:
        ok_(var in r.text, "Did not find '%s' in %s" % (var, r.text))

    for var in invalid_object_types:
        ok_(var not in r.text, "Found (altough I did not want to) '%s' in %s" % (var, r.text))

def test_non_existing_help_page_should_404():
    r = requests.get(api_endpoint+'/horse.head.star.ship', auth=authed_user, verify=False)
    eq_(r.status_code, 404)

def test_limited_user_can_access_help():
    username = 'octoshark'
    password = 'sharktopus'

    user = Crud('user', username)
    user.post({
        'username': username,
        'password': password,
        'groups': ['admins'],
        'modules': ['Default']
    }, cmp=False)

    r = requests.get(api_endpoint, auth=(username, password), verify=False)
    eq_(r.status_code, 200, "Got %d:\n%s" % (r.status_code, r.text))
    user.delete()
    user.verify_gone()
