from op5helpers import *
import itertools
import time

api_endpoint = 'https://'+os.environ.get("MONITOR_SERVER",'localhost')+'/api/'

def test_get_single_object_of_type():
    for obj_type in ["host", "service", "hostgroup", "servicegroup"]:
        url = api_endpoint + 'status/%s/?format=json' % obj_type
        r = requests.get(url, auth=('monitor', 'monitor'), verify=False)
        eq_(r.status_code, 200, "Expected 200 when listing %s, got %d\nurl:\n%s\nbody:\n%s" % (obj_type, r.status_code, url, r.text))
        out = dejson(r.text)
        resource = out[0]['resource']
        r = requests.get(resource, auth=('monitor', 'monitor'), verify=False)
        eq_(r.status_code, 200, "Expected 200 when listing %s, got %d\nurl:\n%s\nbody:\n%s" % (obj_type, r.status_code, resource, r.text))
        dejson(r.text)

def test_list_host():
    hard_options = [None, 0, 1]
    state_options = [0, 1, 2]
    state_options = itertools.chain(
            [None],
            *(itertools.combinations(state_options, x) for x in xrange(1, len(state_options)+1)))
    for hard, state in itertools.product(hard_options, state_options):
        address = api_endpoint + 'status/host?format=json'
        if hard is not None:
            address += '&hard='+str(hard)
        if state is not None:
            for s in state:
                address += '&state[]='+str(s)
        r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
        dejson(r.text)
        eq_(r.status_code, 200, r.text)
    address = api_endpoint + 'status/host?format=json&state=1&state=2&state=0'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_service():
    hard_options = [None, 0, 1]
    state_options = [None, 0, 1, 2, 3]
    state_options = itertools.chain(
            [None],
            *(itertools.combinations(state_options, x) for x in xrange(1, len(state_options)+1)))
    for hard, state in itertools.product(hard_options, state_options):
        address = api_endpoint + 'status/service?format=json'
        if hard is not None:
            address += '&hard='+str(hard)
        if state is not None:
            for s in state:
                address += '&state[]='+str(s)
        r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
        dejson(r.text)
        eq_(r.status_code, 200, "Status code was %s, expected 200: %s" % (r.status_code, r.text))
    address = api_endpoint + 'status/service?format=json&state=1&state=2&state=0'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_hostgroup():
    r = requests.get(api_endpoint + 'status/hostgroup?format=json', auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_servicegroup():
    r = requests.get(api_endpoint + 'status/servicegroup?format=json', auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_status():
    address = api_endpoint + 'status/status'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_contacts():
    address = api_endpoint + 'status/contact'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_contactgroups():
    address = api_endpoint + 'status/contactgroup'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_commands():
    address = api_endpoint + 'status/command'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_timeperiods():
    address = api_endpoint + 'status/timeperiod'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_downtimes():
    address = api_endpoint + 'status/downtime'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_list_comments():
    address = api_endpoint + 'status/comment'
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

def test_limited_get_host():
    username = 'test_somewhat_limited'
    create_user(username, 'test_limited', ['monitor'], ['linux-server1;PING'])
    time.sleep(5)
    r = requests.get(api_endpoint + 'status/host?format=json', auth=(username, 'test_limited'), verify=False)
    out = dejson(r.text)
    eq_(out, [{'resource': api_endpoint + 'status/host/monitor', 'name': 'monitor'}])
    eq_(r.status_code, 200, r.text)
    r = requests.get(api_endpoint + 'status/host/monitor?format=json', auth=(username, 'test_limited'), verify=False)
    out = dejson(r.text)
    eq_(out['name'], 'monitor')
    eq_(r.status_code, 200, r.text)
    r = requests.get(api_endpoint + 'status/host/linux-server1?format=json', auth=(username, 'test_limited'), verify=False)
    eq_(r.status_code, 404, r.text)
    delete_user(username)

def test_limited_get_service():
    username = 'test_a_limited_user'
    create_user(username, 'test_limited', [], ['linux-server1;PING'])
    time.sleep(5)
    r = requests.get(api_endpoint + 'status/service?format=json', auth=(username, 'test_limited'), verify=False)
    out = dejson(r.text)
    eq_(out, [{'resource': api_endpoint + 'status/service/linux-server1%253BPING', 'name': 'linux-server1;PING'}])
    eq_(r.status_code, 200, r.text)
    r = requests.get(api_endpoint + 'status/service/linux-server1;PING?format=json', auth=(username, 'test_limited'), verify=False)
    out = dejson(r.text)
    eq_(out['host_name'], 'linux-server1')
    eq_(r.status_code, 200, r.text)
    r = requests.get(api_endpoint + 'status/service/printer1;PING?format=json', auth=(username, 'test_limited'), verify=False)
    eq_(r.status_code, 404, r.text)
    r = requests.get(api_endpoint + 'status/service/monitor;PING?format=json', auth=(username, 'test_limited'), verify=False)
    eq_(r.status_code, 404, r.text)
    delete_user(username)
    time.sleep(5)

def test_slash_in_service_description():
    crud = Crud("service", "linux-server1;Disk usage /");
    crud.post({
        'host_name': 'linux-server1',
        'service_description': 'Disk usage /',
        'check_command': 'check-host-alive',
    })
    r = requests.post(api_endpoint + 'config/change', auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

    address = api_endpoint + 'status/service/' + quote('linux-server1;Disk usage /')
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    eq_(r.status_code, 200, r.text)


def test_overwrite_inherited_hostgroup_service():
    address = api_endpoint + 'status/service/' + quote('inheritance-host;Inherited-service')
    r = requests.get(address, auth=('monitor', 'monitor'), verify=False)
    eq_(r.status_code, 200, r.text)

    crud = Crud("service", "inheritance-host");
    crud.post({
        'host_name': 'inheritance-host',
        'service_description': 'Inherited-service',
        'check_command': 'check_nt_service',
    })
    r = requests.post(api_endpoint + 'config/change', auth=('monitor', 'monitor'), verify=False)
    dejson(r.text)
    eq_(r.status_code, 200, r.text)

